InRequestGroup

Trait InRequestGroup 

pub trait InRequestGroup<Group> { }
Indicates that a request is part of a request group. If you use the request_group macro to define the group, it will handle the implementation of this trait automatically.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors