pub trait SimpleBody {
type Error;
// Required method
fn simple_body(&self) -> Result<Vec<u8>, Self::Error>;
}Expand description
This allows the send_custom methods to accept objects that do not implement Request. SimpleBody is a more minimal requirement that you get automatically if you implement request, but you can also implement this by itself without implementing Request, to keep things simple with usages of send_custom.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".